@@ -14,7 +14,7 @@ from transformers import (
     Trainer, AutoModelForSeq2SeqLM,
     get_linear_schedule_with_warmup,
     T5ForConditionalGeneration, Adafactor, BartForConditionalGeneration,
-    MT5ForConditionalGeneration, AdamWeightDecay
+    MT5ForConditionalGeneration, AdamWeightDecay, AutoTokenizer
 )
 from wolof_translate.utils.bucket_iterator import SequenceLengthBatchSampler, BucketSampler
 from wolof_translate.utils.sent_transformers import TransformerSequences
